Authors
=======
Since 2021 year this project developing and supporting by Artem Galichkin.

The original project was started in January 2013 by Svyatoslav Bulbakha <mail@ssbb.me>. In 2014-2018, the project was supported by Ivan Gorochov <cwteam@bk.ru>.  After that, the project was abandoned for several years.

Contributors
------------
- Igor
- Hemanth kumar
- juliomax

Other contributors, who commited to `original repository <https://github.com/futurecolors/django-cked>`_:

- Ilya Baryshev
- LinnTroll
- Ilya Lebedev
- Stanislav spanasik
- melevir
